#!/usr/bin/env python

import string
import time
import optparse
import sys
import logging
import traceback
import atexit
import os.path
import pickle

from kraken.Runtime import Runtime
import kraken.Constants
from kraken.tools.Utils import cleanExit, runCommand, cleanStaging
import kraken.Version
from kraken.entrytypes.system.System import createSystem, System

# **************************************************
#   Process the arguments
# **************************************************
def processArguments():
  parser = optparse.OptionParser()
  
  # commands
  parser.add_option("--backup-kraken", dest="theCommand", action="store_const",
                    const="BackupKraken",
                    help="backups the kraken")                    
  parser.add_option("--test", dest="theCommand", action="store_const", 
                    const="TestKraken",
                    help="run the self test of the kraken")  
  # configuration options
  parser.add_option("-i","--interactive", dest="interactive", action="store_true",
                    help="interactive entry (persistent)")
  parser.add_option("--non-interactive", dest="interactive", action="store_false",
                    help="non interactive entry (persistent)")
  parser.add_option("--inputfile", dest="inputFile",
                    help="the inputfile", metavar="FILE")
  parser.add_option("--inputhttp", dest="inputHttp",
                    help="the input webaddress", metavar="SIZE")
  parser.add_option("-r", "--recursive", dest="recursive", action="store_true",
                    help="recursive download of the webpage")
  parser.add_option("--annotate-entry", dest="annotateEntry",
                    help="annotate the specified entry", metavar="ENTRY")
  parser.add_option("--title", dest="title",
                    help="the title of the page", metavar="TITLE")
  parser.add_option("--description", dest="description",
                    help="the description of the page", metavar="DESCRIPTION")
  parser.add_option("--date", dest="tmpDate",
                    help="date of file (mm/dd/yy)", metavar="DATE")
  parser.add_option("--force-regenerate-cache", dest="forceRegenerateCache",
                    action="store_true",
                    help="forces the regeneration of the cache")

  # General commands
  parser.add_option("--command", dest="theCommand",
                    help="Execute command COMMAND", metavar="COMMAND")
  parser.add_option("--describe-command", dest="commandToDescribe",
                    help="Describe the specified command", metavar="COMMAND")
  parser.add_option("--list-all-commands", dest="theCommand",
                    action="store_const", const="ListAllCommands",                    
                    help="list all the commands")
  
                   
  # Commands for listing, generating and querying
                    
  parser.add_option("--generate-text", dest="theCommand", action="store_const",
                    const="GenerateText",
                    help="generate a text listing")
  parser.add_option("-g", "--generate-html", dest="theCommand", action="store_const",
                    const="GenerateHTML",
                    help="generate a html page")                    
  parser.add_option("--show-config", dest="theCommand", action="store_const",
                    const="ShowConfiguration",
                    help="shows the configuration")
  parser.add_option("--show-summary", dest="theCommand", action="store_const",
                    const="ShowSummary",
                    help="shows a summary of the content of the kraken")                    
  parser.add_option("-e", "--embrace-entries", dest="theCommand", action="store_const",
                    const="EmbraceEntries",
                    help="embrace entries from directories.")                    
  # define output                    
  parser.add_option("--outputfile", dest="outputFile",
                    help="the outputfile for generate commands", metavar="FILE")
                                        
  (options, runtime.arguments) = parser.parse_args(values=runtime)
  
def postProcessArguments():  
  # directory to add / remove
  if runtime.annotateEntry != None:
      runtime.theCommand = "AnnotateEntry"
  
  # process the date, if any
  if runtime.tmpDate != "":
      try:
        runtime.date = time.strptime(runtime.tmpDate, "%m/%d/%y")
      except:
        cleanExit(system, runtime, 1,
           "Error: " + runtime.tmpDate + " is not a valid date. Use mm/dd/yy format!")
  
  # process the runtime argument                
  if len(runtime.arguments) >= 1:
      runtime.theCommand = "CreateEntry"
      

#
# saves the system file
#    
def saveSystem(sys):
    print "Saving system..."
    filename = os.path.expanduser(kraken.Constants.SYSTEM_FILE)
    sys.writeEntryToRdf(filename)    
    
# **************************************************
#
#   The main program
#
# **************************************************

print "Kraken " + kraken.Version.versionNumber + " of " + kraken.Version.date + " (c) Lotzi Boloni"
print sys.argv

runtime = Runtime()
processArguments()
system = createSystem()
atexit.register(saveSystem, system)
postProcessArguments()
while 1:    
    cleanStaging(system)
    runCommand(runtime.theCommand, system, runtime) 
