import logging
import os
import os.path
import pprint
import kraken.tools.TextUi as TextUi
from kraken.entrytypes.Entry import Entry, getEntryRdfFile
from kraken.entrytypes.MetaData import loadMetaData, updateCache

def description(system, runtime):
    return """
    Embrace the entries in the kraken directories which do not have
     metadata associated with them.
    """

#
#  Embrace entries
#      
def execute(system, runtime):
    metadata = loadMetaData(system, runtime)
    entriesToEmbrace = []
    for kd in system.getProperty("krakenDirs"):
        for x in os.listdir(kd):
           entrypath = os.path.join(kd, x)            
           if not os.path.isdir(entrypath):
               continue
           if os.path.exists(getEntryRdfFile(entrypath)):
               continue           
           entriesToEmbrace.append((kd, x))
    print "There are " + str(len(entriesToEmbrace)) + " entries without metadata."
    #print entriesToEmbrace
    for a in entriesToEmbrace:
        __embraceSingleEntry(a[0], a[1], system, runtime, metadata)
    updateCache(system, runtime, metadata)
       

#
#  Embrace a single directory
#           
def __embraceSingleEntry(krakenDir, dirName, system, runtime, metadata):
    dirToEmbrace = os.path.join(krakenDir, dirName)
    files = os.listdir(dirToEmbrace)
    print "\nEmbracing entry: " + dirName
    print "From directory: " + os.path.join(krakenDir, dirName)
    pp = pprint.PrettyPrinter(indent = 4)
    print "Contents of directory:\n" + pp.pformat(files) + "\n"
    if not TextUi.confirm("Should I proceed with embracing?"):
        return
    entry = Entry()
    entry.addProperty("directoryName", dirName)
    entry.parentDirName = krakenDir
    print "Kraken dir name is:" + entry.parentDirName
    # this will guarantee that the metadata dir is created
    entry.writeRDF(dirToEmbrace)
    if (len(files) <= 3):
        entry.addProperty("localFileNames", files) 
    entry.edit(metadata)
    entry.writeRDF(dirToEmbrace)
    metadata.addEntry(entry)    
    
