from rdflib.URIRef import URIRef
from rdflib.Namespace import Namespace
from kraken.entrytypes.EntryBase import EntryBase
from kraken.entrytypes.Secondary import Secondary
from kraken.tools.UniqueIdGenerator import getUniqueId
import time


class Opinion(EntryBase, Secondary):

  # the self description of the class
  namespaces = {}
  # the namespaces  
  namespaces["opinion"] = "http://www.cs.ucf.edu/~lboloni/Programming/KrakenWeb/Opinion/"
  OPINION = Namespace(namespaces["opinion"]);

  #
  #   -----------  properties
  #
  allowed_properties = [
    "id",
    'ranking',
    'lastVisited',
    'lastModified',
    'opinionOf',
    'opinionAbout',
    'trust',
    'activity'
    ]
  
  def __init__(self):
      EntryBase.__init__(self)
      self.filecontents_source = ""
      self.resourceURI = URIRef("opinion://" + getUniqueId())
      # initialize the fields, to set the types - this is needed for the time
      self.addProperty("id", "")
      self.addProperty("ranking", 0)
      self.addProperty("lastVisited", time.localtime())
      self.addProperty("lastModified", time.localtime())
      self.addProperty("opinionOf","")
      self.addProperty("trust", 100) # perfect trust by default
      self.addProperty("activity", 100) # activity percentile, starts by being fully active

  def getMapping(self, field):
      return self.OPINION[field]
      
  def getResourceURI(self):
      return self.resourceURI
#
#   -----------      properties accessors
#
  def getType(self):
      return self.fields["type"]
      
  #
  #  Command line based editing of an entry - mainly for annotation, etc
  #            
  def edit(self, metadata = None):
      print "Opinion"
      self.editField("ranking", "Ranking [0-100]")
      self.editField("trust", "Trust [-100, 100]")
      self.editField("activity", "Activity [0-100]")

def createEmpty(entry, descriptor):
    op = Opinion()
    rdfFileName = descriptor.getRdfFileName(entry)
    op.writeEntryToRdf(rdfFileName)
    
def editOpinion(entry, descriptor):
    op = descriptor.loadSecondary(entry)
    op.edit()
    rdfFileName = descriptor.getRdfFileName(entry)
    op.writeEntryToRdf(rdfFileName) 
