import time
import os.path
import logging
from types import *
import pickle

from rdflib.URIRef import URIRef
from rdflib.Literal import Literal
from rdflib.Namespace import Namespace
from kraken.entrytypes.EntryBase import EntryBase
from kraken.tools.UniqueIdGenerator import getUniqueId
import kraken.Constants

class System(EntryBase):

  # the self description of the class
  namespaces = {}
  # the namespaces  
  namespaces["kraken"] = "http://www.cs.ucf.edu/~lboloni/Programming/KrakenWeb/"
  KRAKEN = Namespace(namespaces["kraken"]);

  #
  #   -----------  properties
  #
  allowed_properties = [
    "destinationDir",
    'krakenDirs',
    'linkDir',
    'generatedEntryDir',
    'tempDir',
    'filterDir',
    'htmlDir'
    ]
    
  def __init__(self):
      EntryBase.__init__(self)
      self.resourceURI = URIRef("opinion://" + getUniqueId())
      # initialize the fields, to set the types - this is needed for the time
      self.addProperty("destinationDir", os.path.expanduser(kraken.Constants.DEFAULT_DESTINATION_DIR))
      self.addProperty("krakenDirs", [self.getProperty("destinationDir")])
      self.addProperty("linkDir", os.path.expanduser(kraken.Constants.DEFAULT_LINK_DIR))
      self.addProperty("generatedEntryDir", os.path.expanduser(kraken.Constants.DEFAULT_GENERATED_ENTRY_DIR))
      self.addProperty("tempDir", os.path.expanduser(kraken.Constants.DEFAULT_STAGING_DIR))
      self.addProperty("filterDir", os.path.expanduser(kraken.Constants.DEFAULT_FILTER_DIR))
      self.addProperty("htmlDir", os.path.expanduser(kraken.Constants.DEFAULT_HTML_DIR))

  def getMapping(self, field):
      return self.KRAKEN[field]
      
  def getResourceURI(self):
      return self.resourceURI

  def __str__(self):
      t = "Kraken system entry:\n"
      for property_name in self.fields.keys():
        t += "\t" + property_name + "\t = " + str(self.fields[property_name])+ "\n"
      return t
      
  #
  #  Command line based editing of an entry - mainly for annotation, etc
  #            
  def edit(self, metadata = None):
      print "System configuration file"
      self.editField("destinationDir")
      self.editField("krakenDirs")
      self.editField("linkDir")
      self.editField("generatedEntryDir")
      self.editField("tempDir")


#
# creates the config file, either by loading it, or creating a new one
# 
def createSystem():
    # try loading from the rdf
    sysfile = os.path.expanduser(kraken.Constants.SYSTEM_FILE)
    sys = System()
    if os.path.exists(sysfile):
        print "Loading config from system file"
        sys.readEntryFromRdf(sysfile)
    else:
        logging.info("Could not find system file:" + sysfile + ". Going with defaults.")
    return sys
    # The directories need to end with "/"
#    config.checkStagingDir()
    return sys


      
